@@ -35,25 +35,17 @@ class MCDS(xr.Dataset):
         -------
         MCDS
         """
-        if use_obs is not None:
-            def preprocess(_ds):
-                _use_obs = use_obs & _ds.get_index(obs_dim)
-                _ds = _ds.sel({obs_dim: _use_obs})
-                return _ds
-        else:
-            preprocess = None
-
         if isinstance(mcds_paths, str) and '*' not in mcds_paths:
             ds = xr.open_dataset(mcds_paths)
-            if preprocess is not None:
-                ds = preprocess(ds)
         else:
             with dask.config.set(**{'array.slicing.split_large_chunks': False}):
                 ds = xr.open_mfdataset(mcds_paths,
-                                       preprocess=preprocess,
                                        parallel=False,
                                        combine='nested',
                                        concat_dim=obs_dim)
+        if use_obs is not None:
+            use_obs = ds.get_index(obs_dim).intersection(use_obs)
+            ds = ds.sel({obs_dim: use_obs})
         return cls(ds).squeeze()
 
     def add_mc_frac(self,
@@ -120,8 +112,8 @@ class MCDS(xr.Dataset):
         -------
         None
         """
-        feature_cov_mean = self[f'{var_dim}_da'].squeeze().sel(
-            count_type='cov').sum(dim='mc_type').mean(dim=obs_dim).to_pandas()
+        feature_cov_mean = self[f'{var_dim}_da'].sel(
+            count_type='cov').sum(dim='mc_type').mean(dim=obs_dim).squeeze().to_pandas()
         self.coords[f'{var_dim}_cov_mean'] = feature_cov_mean
 
         print(f"Feature {var_dim} mean cov across cells added in MCDS.coords['{var_dim}_cov_mean'].")
@@ -211,8 +203,12 @@ class MCDS(xr.Dataset):
             feature_bed = BedTool.from_dataframe(feature_bed_df)
             black_list_bed = BedTool(black_list_path)
             black_feature = feature_bed.intersect(black_list_bed, f=f, wa=True)
-            black_feature_index = black_feature.to_dataframe().set_index(
-                ['chrom', 'start', 'end']).index
+            try:
+                black_feature_index = black_feature.to_dataframe().set_index(
+                    ['chrom', 'start', 'end']).index
+            except pd.errors.EmptyDataError:
+                print('No feature overlapping the black list bed file.')
+                return self
         black_feature_id = pd.Index(
             feature_bed_df.reset_index().set_index(['chrom', 'start', 'end']).loc[black_feature_index][var_dim])
 
